package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````4"(```````!``````````""Q````
M`````````$``.``+`$``&@`9``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````#@;````````.!L`````````
M$`````````$````%`````"``````````(``````````@````````S3P`````
M``#-/``````````0`````````0````0`````8`````````!@`````````&``
M``````#P1````````/!$`````````!`````````!````!@```*BK````````
MJ+L```````"HNP```````'@$`````````!4`````````$`````````(````&
M````N*L```````"XNP```````+B[````````(`(````````@`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)T```````"`G0``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"HJP```````*B[````````J+L```````!8!````````%@$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`$J4GBZM<OO(`<Y\CVQ(?N_;Q(-<!````!`````!````1TY5```````#
M`````@`````````]````0P````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(01;H``@H``````````$,`````````1````$8```!(````````
M`$D`````````2@```$L```!,````3@``````````````3P``````````````
M``````````````````````````!0````40```%,```!5````````````````
M````5@````````!7`````````%@``````````````%D```!:`````````%L`
M``!<````````````````````70````````!>``````````````!?````8```
M`&(``````````````&,`````````````````````````N^.2?*;=HVMK&IY0
M+L6;MD/ZUX<5C"7,9Z_,9F_%WQ^)!W#3Q(D%D*/@^TG[H6Q@U634?,/E/RQ^
MJ9R;K4OCP.)'Q@'/WD<M#13BGB'_Y`[AIP(*V\WCG@N*$%>S`8MO#3J7"]EQ
M6!Q7I)N6,V+;[6L)0];$N9Q`.?*+'$-%U>QK?YI\````````````````````
M````````````2`$``!(`````````````````````````N`$``!(`````````
M````````````````$@(``!(`````````````````````````\`$``!(`````
M`````````````````````0```"``````````````````````````&0(``!(`
M````````````````````````I0(``!(`````````````````````````8P``
M`!(`````````````````````````+@(``!(`````````````````````````
MQ0```!(`````````````````````````C0(``!(`````````````````````
M````A0(``!(`````````````````````````!@$``!(`````````````````
M````````>`,``!(`````````````````````````0P$``!(`````````````
M````````````40(``!(`````````````````````````0P(``!(`````````
M`````````````````0(``!(`````````````````````````G@(``!(`````
M````````````````````K@(``!(`````````````````````````%0$``!(`
M````````````````````````Z0```!(`````````````````````````G```
M`!(`````````````````````````(P$``!(`````````````````````````
MY0$``!(`````````````````````````^`$``!(`````````````````````
M````#@,``!(`````````````````````````30$``!(`````````````````
M````````)P(``!(`````````````````````````LP$``!(`````````````
M````````````\@(``!(`````````````````````````ZP(``!(`````````
M````````````````4P```!(`````````````````````````'0```"``````
M````````````````````90(``!(`````````````````````````8`$``!(`
M````````````````````````T0$``!(`````````````````````````60$`
M`!(`````````````````````````K@```!(`````````````````````````
M+@$``!(`````````````````````````N@```!(`````````````````````
M````@`$``!(`````````````````````````DP$``!(`````````````````
M````````?P```!(`````````````````````````;`(``!(`````````````
M````````````W@```!(`````````````````````````;P$``!(`````````
M````````````````'P(``!(`````````````````````````K`$``!(`````
M````````````````````W`(``!(`````````````````````````M0(``!(`
M````````````````````````<0```!(`````````````````````````BP``
M`!(`````````````````````````Y`(``!(`````````````````````````
M/`(``!(`````````````````````````]P```!(`````````````````````
M````U0```!(`````````````````````````>@(``!(`````````````````
M````````ZP$``!(`````````````````````````R0$``!(`````````````
M````````````5P(``!(`````````````````````````+````"``````````
M````````````````-0(``!(`````````````````````````OP(``"(`````
M````````````````````2@(``!(`````````````````````````S@(``!(`
M````````````````````````$00``!``%P"HT```````````````````!@,`
M`"$`%P!`P`````````@`````````(P0``!(`#0`P6@```````/L!````````
M50,``!(`#0#0*P````````4`````````N@,``!(`#0"`6````````*<!````
M````;@0``!(`#0`@6````````%4`````````H0,``!(`#0`@+@```````!T`
M````````@0,``!(`#0#`0````````#\!````````!P0``!$`%@`8P```````
M``@`````````!0,``"$`%P!`P`````````@`````````%@0``!(`#0!`+@``
M`````*<$````````3@0``!(`#0"0,P```````!`!````````=P0``!(`#0"P
M/`````````X$````````.00``!(`#0#`*@```````#(`````````9@,``!(`
M#0!P,P```````!\`````````T@,``!$`#P``8`````````0`````````E`,`
M`!(`#0#P+0```````"4`````````K0,``!(`#0"@-`````````$(````````
M10,``!(`#0"@7`````````4`````````000``!(`#0#@*P````````4"````
M````X0,``!(`#0``*P```````,4`````````]P,``!(`#0`P7````````&4`
M````````1@```!$`%P`PP`````````$`````````8`0``!(`#0#P,@``````
M`'4`````````QP,``"``%@``P```````````````````+00``!``%P`@P```
M````````````````H0$``!$`%P`@P`````````0`````````RP,``!(`#0!0
M(@```````"\`````````Q0,``!``%@``P```````````````````!`,``!$`
M%P!`P`````````@`````````EP(``!$`%P!@P`````````@`````````C0,`
M`!``%@`@P```````````````````_P(``!(`#0!`(````````!`"````````
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V
M7V9E=&-H<'8`4&5R;%]A=E]S:&EF=`!097)L7V%V7V9E=&-H`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7VQO8VL`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]G
M971?<W8`4&5R;%]N97=84P!B;V]T7T1Y;F%,;V%D97(`<&5R;%]R=6X`<&5R
M;%]P87)S90!097)L7W-V7W-E='!V`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?8V]N
M<W1R=6-T`'!E<FQ?9&5S=')U8W0`<&5R;%]A;&QO8P!097)L7V-R;V%K7VYO
M8V]N=&5X=`!P97)L7V9R964`4&5R;%]S869E<WES;6%L;&]C`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO
M8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET
M`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N
M`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?
M8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O
M`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`7U]L:6)C7V-S=5]F:6YI`'!A
M<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7V5D871A`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S
M960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T
M`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E
M;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#
M7S(N,BXU`$=,24)#7S(N,RXT`$=,24)#7S(N,30`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXT`"]U<W(O;&EB+W!E<FPU+S4N,S(O8V]R95]P97)L+T-/4D4`````
M`@`#``(``@````(``@````(````"``(````"`````@`"``0``@`"````````
M`````P`"``4````"``,``@`"```````&`````P`"``````````````````<`
M``````(``P`"``(```````(``@```````@`"``,`!P````(``@`"``<``0`"
M``$``0`!``$``0`!``$``@`!``$``0`!``$``0`!``$``0`!``$``0````$`
M`0`!`````0`!``(``@`!``$``````````0`!`"L#```0````(````'4::0D`
M``,`C00````````!``4`.P,``!``````````=!EI"0``!P"9!```$````)21
ME@8```8`I00``!````!R&6D)```%`+`$```0````%&EI#0``!`"\!```$```
M`'4::0D```(`C00```````"HNP````````@`````````0",```````"PNP``
M``````@`````````\"(````````(P`````````@`````````",`````````8
MP`````````@`````````X&(```````#XO0````````8````!````````````
M````O@````````8````"```````````````(O@````````8````#````````
M```````0O@````````8````$```````````````8O@````````8````%````
M```````````@O@````````8````&```````````````HO@````````8````'
M```````````````PO@````````8````(```````````````XO@````````8`
M```)``````````````!`O@````````8````*``````````````!(O@``````
M``8````+``````````````!0O@````````8````,``````````````!8O@``
M``````8````-``````````````!@O@````````8````.``````````````!H
MO@````````8````/``````````````!PO@````````8````0````````````
M``!XO@````````8````1``````````````"`O@````````8````2````````
M``````"(O@````````8````3``````````````"0O@````````8````4````
M``````````"8O@````````8````5``````````````"@O@````````8````6
M``````````````"HO@````````8````7``````````````"PO@````````8`
M```8``````````````"XO@````````8````9``````````````#`O@``````
M``8````:``````````````#(O@````````8````<``````````````#0O@``
M``````8````=``````````````#8O@````````8````>``````````````#@
MO@````````8````?``````````````#HO@````````8````@````````````
M``#PO@````````8````A``````````````#XO@````````8````B````````
M````````OP````````8````C```````````````(OP````````8````D````
M```````````0OP````````8````E```````````````8OP````````8````F
M```````````````@OP````````8````G```````````````HOP````````8`
M```H```````````````POP````````8````I```````````````XOP``````
M``8````J``````````````!`OP````````8````K``````````````!(OP``
M``````8````L``````````````!0OP````````8````M``````````````!8
MOP````````8````N``````````````!@OP````````8````O````````````
M``!HOP````````8````P``````````````!POP````````8````Q````````
M``````!XOP````````8````R``````````````"`OP````````8````S````
M``````````"(OP````````8````T``````````````"0OP````````8````U
M``````````````"8OP````````8````V``````````````"@OP````````8`
M```W``````````````"HOP````````8````X``````````````"POP``````
M``8````Y``````````````"XOP````````8````Z``````````````#`OP``
M``````8````[``````````````#(OP````````8````\``````````````#0
MOP````````8````]``````````````#8OP````````8````^````````````
M``#@OP````````8````_``````````````#HOP````````8```!`````````
M``````#POP````````8```!!``````````````#XOP````````8```!"````
M```````````@P`````````4```!=```````````````PP`````````4```!9
M``````````````!`P`````````4```!@``````````````!@P`````````4`
M``!A``````````````#PO0````````<````;````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!>F>``!(A<!T`O_02(/$",,``````/\UNIT``/\EO)T`
M``\?0`#_);J=``!H`````.G@____05152(/L.(E\)!Q(C7PD'$B)="002(UT
M)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP/\5CIX``$B+-;>>``!(BST(
MGP``2(GR9^@?/```@#V8GP```'4R_Q40G@``2(D%^:\``$B)QTB%P`^$D@$`
M`/\5GYT``(L]89\``/\52YX``,:`Z0D```"+/4Z?``#_%3B>``"+/4*?``"`
MB#H$```"_Q4EG@``@(@Z!````8M$)!R->`5(8_](P><#_Q7"G0``2(M\)!!,
M8T0D',<%=J\```0```!(B<%(B05DKP``2(L'38G!2(D!2(T%G4```$B)00A(
MBP79G@``2(E!$$B-!8I```!(B4$8N`$```!!@_@!?AX/'X``````2(LTQXU0
M`TB#P`%(8])(B3313#G`=>E!C5$#2(L]'J\``$4QP$B--<0(``!(8\)(QP3!
M`````/\5NYT``$&)Q(7`=%9(C6PD)$B+/?"N``#_%>*<```QP$B)[DB-/>$^
M``#HB0$``$B%P'1`2(L]S:X``/\5CYP``/\589T``$B+1"0H9$@K!"4H````
M=5!(@\0X1(G@74%<PTB+/9^N``#_%:F=``!!B<3KF$B+/86N``!(A?]T!^BC
M'@``ZZU(C3TT/@``2(GNZ"(!``!(B05CK@``2(G'2(7`=(_KV?\5.YP``+\!
M````_Q5PG0``\P\>^C'M28G17DB)XDB#Y/!05$R-!38Z``!(C0V_.0``2(T]
MR/W___\58IP``/202(T]F9T``$B-!9*=``!(.?AT%4B+!7Z;``!(A<!T"?_@
M#Q^``````,,/'X``````2(T]:9T``$B--6*=``!(*?Y(B?!(P>X_2,'X`T@!
MQDC1_G042(L%_9P``$B%P'0(_^!F#Q]$``###Q^``````/,/'OJ`/6V=````
M=3-52(,]XIP```!(B>5T#4B+/?:<``#_%="<``#H8____\8%1)T```%=PV8N
M#Q^$``````##9F8N#Q^$```````/'T``\P\>^NEG____#Q^``````$%7059!
M54%455-(@^P(2(7_#X2Q````3(LMTIP``$V%[0^$H0````^V!TF)_TB)]83`
M=`0\/75813'V38ME`$V%Y'0S36/V3(GK9@\?1```3(GR3(G^3(GG_Q5AF@``
MA<!U!T.`/#0]=$9,BV,(2(/#"$V%Y'792(/$"$R)X%M=05Q!74%>05_##Q^`
M`````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````3"GK3XUD-`%(
MP?L#B5T`Z[8/'X``````13'DZZH/'P!!5D%505154TB![*````!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K!"4H````#X5!
M`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#_%<J9``!)B<1(A<!TP4F)
MY4R)Y_\5YIH``$B%P`^$O0```(!X$RY(C5@3=0N`>P$`=-X/'T0``(!X$RX/
MA+X```!(B>__%:V9``!(B=])B<;_%:&9``!!C7P&`DAC__\5,YH``$F)V4F)
MZ+X!````28G&2(G',<!(Q\+_____2(T-_CH``/\5[)H``+\!````3(GJ3(GV
M_Q4KF0``3(GW@_C_=!"+1"08)0#P```]`$```'1K_Q7-F```3(GW_Q6TF```
M3(GG_Q4SF@``2(7`#X5-____9BX/'X0``````$R)Y_\55YD``$B)[_\5_I@`
M`.G8_O__9@\?A```````@'L!+@^%./___X![`@`/A/W^___I*?___P\?@```
M``#H>_[__^N4_Q73F```#Q\`54B)_DB)_;\!````2('LH````&1(BP0E*```
M`$B)A"28````,<!(B>+_%=F9``"%P'4UBU0D&('B`/```('Z`$```'0(@?H`
MH```=1V^`@```$B)[_\5C9D``(7`#Y3`#[;`ZP4/'P`QP$B+C"28````9$@K
M#"4H````=0E(@<2@````7</_%428```/'T``54B)_?\5+I@``$B-5`7_2#G5
M<A7ID0````\?@`````!(@^H!2#G5="6`.B]T\D@YU7-W2(/J`4@YU702#Q]`
M`(`Z+W0H2(/J`4@YU77R@'T`+W1D2(T]<3D``%W_)3Z9``!F#Q]$``"`.B]U
M"4B#Z@%(.=5R\D@IZC'`2(U*`DB!^0`0``!W($B#P@&Y`!```$B)[DB-/:69
M``#_%6^8``!(C068F0``7<-(.=5UONN=#Q^``````$B-/0LY``!=_R7:F```
M9BX/'X0``````$%7NO\/``!!5D%5051)B?152(G]2(T]XS@``$B![!`0``!D
M2(L$)2@```!(B80D"!```#'`28GE3(GN_Q77E@``A<!^>XU0_T2+/<&8``!,
M8_)"@#PT`'5?A=)T:DR)\KXO````3(GO_Q52EP``2(7`=%1$B?__%827``!,
MB?%,B>I(B>Y(B<?_%0J8``!(BX0D"!```&1(*P0E*````'5`2('$$!```%U!
M7$%=05Y!7\-F#Q]$``!,8_#KH`\?`$2+/4F8``!$B?__%3"7``!,B>)(B>Y(
MB<?_%;&6``#KK?\5B98``&8/'X0``````$%7059!54%454B)]5-(B?M(@^P8
M9$B+!"4H````2(E$)`@QP#'`@#X]#Y3`2`'%2(GO_Q5`E@``2(UT)`1(B=])
MB<0QP.@&^___2(7`#X0-`0``28G%2(G'_Q49E@``23G$#X;8````3&-T)`1)
MP>8##[8#A,`/A*P!```\/0^$I`$``$B)V&8/'X0```````^V4`%(@\`!A-)T
M!8#Z/77O2"G82)A,`S63EP``2HU\(`+_%6"6``!)B09(A<!T64B+!7F7``!(
M8U0D!$B-2P%(BQ30#[8#B`*$P'0@/#UU"^L:#Q]$``"$P'01#[8!2(/"`4B#
MP0&(`CP]=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$
M)2@````/A0\!``!(@\086UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSW9E@``28,_``^$O@```$R)^$4Q[68/'X0`
M`````$B#P`A$B>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%WZ8``(7`=5O'!=&F
M```!````2(GW_Q5@E0``2(7`#X18____36/U3(G^2(G'2<'F`TR)\O\5H94`
M`$B)!6*6``!(B<%!C44!2)A(QP3!`````$2);"0$Z7C^__\/'X``````3(G_
M_Q5?E0``2(D%,)8``$B)P4B%P`^$_?[__TUC]4G!Y@/KO`\?`#'`Z7?^__^^
M$````$4Q[>E?_____Q4^E```9F8N#Q^$```````/'P!(@^P(BSW&E0``_Q6P
ME```BSVZE0``_Q6DE```2(L5S9,``$B-#<YR``!(C36<-0``2(G'_Q6FE```
MBSV0E0``_Q5ZE```3(T%$S<``$4QR4B-%0D2``!(B<=,B<%(C36%-0``2(/$
M"/\EHI0``&:02(/L"(L]5I4``/\50)0``$B+%6F3``!(@\0(2(T-9G(``$B)
MQTB--3$U``#_)3Z4``!F9BX/'X0```````\?`$%455-(@>P@(```9$B+!"4H
M````2(F$)!@@```QP$B)Y4R-I"00$```_Q4)DP``3(T-XS0``+H!$```2(GO
M08G`2(T-!C4``+X!````,<#_%:.4``"Z`!```$R)YDB)[_\5PI(``$4QP(7`
M>#"->`%(B<-(8___%9R3``!)B<!(A<!T&4ACVTR)YDB)QTB)VO\5:I,``,8$
M&`!)B<!(BX0D&"```&1(*P0E*````'4/2('$("```$R)P%M=05S#_Q6[D@``
M9F8N#Q^$``````#I*____V9F+@\?A```````05=!5D%528GU05152(G]2(T]
M9#0``%-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z#7W__^^+P``
M`$B)[TB)P_\59)(``$B%P'0_,<!(B>Y(C3TF-```Z+[[__](B>A(BYPDJ!``
M`&1(*QPE*`````^%@P$``$B!Q+@0``!;74%<05U!7D%?PV:02(GO_Q7_D0``
M2(TU\#,``$R)[T&)Q/\5%),``$F)QDB%P'2=08`^`$R-+6LS```/A-\````/
M'P!(A=MT%$R)]DB)W_\5+Y(``(7`#X2>````3(GW_Q6ND0``C5#_B<%(8\),
M`?"`."]U&68/'T0``(G1@^H!Q@``2&/"3`'P@#@O=.U"C40A`3W_#P``#X\N
M____38GPN@`0``"^`0```#'`3(V\)*````!(@^P(2(T-030``%5,C0W?,@``
M3(G__Q7"D@``3(G^OP$```!(C50D(/\5_Y```%I9A<!U$(M$)"@E`/```#T`
M@```=%%(C34*,P``,?__%3*2``!)B<9(A<`/A+?^__]!@#X`#X4D____2(7;
M=`6`.RYT$DV)[KD!````Z5C___\/'T0``(![`0!TN>OF#Q^$``````"^`0``
M`$R)__\5VI$``(7`=9U,B?Y(C3V7,@``Z"_Z__],B?__%0:2``#I9O[___\5
MFY```&9F+@\?A```````#[8'28GXA,!T%V8/'T0``$B#QP$\+P^V!TP/1,>$
MP'7O3(G`PV9F+@\?A```````2(7_=`N`/P!T!ND1^/__D$B-/=,Q``#_):.1
M```/'P!54TB-'2DR``!(@^Q(9@]O!0MO``!D2(L$)2@```!(B40D.#'`,<!(
MC6PD#`\11"009@]O!?=N``!FB40D,`\11"0@#Q]$```QP$B)[DB)W^B[]/__
M2(7`=#Y(8U0D#$B+!9J1``!(C0302(M0"$B)$$B%TG329BX/'X0``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'9PQ``"0,<!(B>Y(B=_H8_3__TB%
MP'0V2&-4)`Q(BP5"D0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(T=5#$``)`QP$B)[DB)W^@3]/__2(7`=#9(8U0D#$B+
M!?*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(C1T-,0``D#'`2(GN2(G?Z,/S__](A<!T-DAC5"0,2(L%HI```$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'<0P``"0
M,<!(B>Y(B=_H<_/__TB%P'0V2&-4)`Q(BP52D```2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=A#```)`QP$B)[DB)W^@C
M\___2(7`=#9(8U0D#$B+!0*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(C1WK+P``D#'`2(GN2(G?Z-/R__](A<!T-DAC
M5"0,2(L%LH\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$B-'?`O``"0,<!(B>Y(B=_H@_+__TB%P'0V2&-4)`Q(BP5BCP``
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=
MJB\``)`QP$B)[DB)W^@S\O__2(7`=#9(8U0D#$B+!1*/``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1UD+P``D#'`2(GN
M2(G?Z./Q__](A<!T-DAC5"0,2(L%PHX``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$B-';0N``"0,<!(B>Y(B=_HD_'__TB%
MP'0V2&-4)`Q(BP5RC@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(GN2(T]RRX``.A)\?__2(G&2(7`=`Y(C3VC+@``,<#H
MX_7__TB)[DB-/;<N```QP.@B\?__2(G&2(7`=`Y(C3VS+@``,<#HO/7__TB)
M[DB-/:TN```QP.C[\/__2(G&2(7`=#I(C3WV+0``,<#HE?7__S'`2(TULRX`
M`$B-/1@N``#H@/7__TB+1"0X9$@K!"4H````=5%(@\1(6UW#2(GN2(T]:BX`
M`#'`Z*CP__](B<9(A<!T$$B-/?@M```QP.A"]?__ZZM(N%!!4E]#3$5!2#E$
M)"%UFF:!?"0I3CUUD4B-="0KZ\__%9F+``!F#Q^$``````!(@^P89$B+!"4H
M````2(E$)`B+!0B-``"#^/]T&TB+?"0(9$@K/"4H````=4)(@\08PV8/'T0`
M`$B-="0$2(T]>RT``#'`Z!7P__](B<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5
MP"'(B06SC```ZZ[_%1N+``!F9BX/'X0``````$B#[`C_%0Z+``")Q_\5WHH`
M`$B%P'0#2(L`2(/$",.005152(G]2(T]C"T``%-(@^P09$B+!"4H````2(E$
M)`@QP$B-="0$Z)3O__](A<!T"(`X`$B)PW4W2(M$)`AD2"L$)2@````/A;T`
M``!(B>Y(@\002(T]/BT``#'`6UU!7.D*]/__9BX/'X0``````$B)[DB)Q_\5
MY(L``$B%P'0?2(M$)`AD2"L$)2@```!U>4B#Q!!;74%<PV8/'T0``$B)[_\5
M/XH``$B)WTF)Q/\5,XH``$F-?`0"_Q7(B@``2(/L"$F)Z+X!````4TC'PO__
M__](B<=)B<1,C0W_*P``2(T-[BP``#'`_Q5XBP``6%I(BT0D"&1(*P0E*```
M`'4(3(GFZ4;_____%>")``!!5T%6055)B?U(C3VJ*P``05154TB![(B!``!D
M2(L$)2@```!(B80D>($``$B-!7(L``!,C60D'$C'1"0P`````$C'A"2(````
M`````$R)YDC'1"10`````$B)1"0@2(T%!2L``$B)1"0H2(T%V"L``$B)1"1H
M2(T%+2P``$B)1"1P2(T%W2L``$B)1"1X2(T%'2P``$B)A"2`````2(T%$BP`
M`$B)1"1(,<#H`.[__TB%P'0,@#@`2(G%#X6O!```_Q4AB0``B<?_%?&(``!(
MA<`/A/@#``!(BRA(A>T/A.P#``!(B>__%>N(``!(C7P``?\5@(D``$0/MD4`
M2(G#183`=#=)B=],C36P*P``D$B#Q0%,B?],B?&^`0```$C'PO____\QP$F#
MQP+_%2:*``!$#[9%`$6$P'743(UT)&!(C3T(*P``ZQ=F#Q]$``!)BWX(28/&
M"$B%_P^$/P$``$R)YC'`Z$7M__](B<5(A<!TW8`X`'382(G'Z)#O__^%P'3,
M2(GO_Q6SB0``28G'2(7`#X0'`0``#Q^``````$R)__\5+X@``$B)WTB)Q?\5
M(X@``$2-M`4$!```36/V3(GW_Q6OB```4TV)^$R-#9@I``!(B<5(C07O*@``
MO@$```!(Q\+_____4$B-#=(J``!(B>\QP/\56XD``$B)[[[``0``_Q5UAP``
M7T%8@_C_=1/_%4>'``!$BPA!@_D1#X4@`P``2(V4))````!(B>Z_`0```/\5
MW(@``(G#A<`/A+H```!)BTT`2(L];XD``$F)Z#'`2(T5&RL``+X!````13'V
M_Q7%B```2(N$)'B!``!D2"L$)2@````/A7D%``!(@<2(@0``3(GP6UU!7$%=
M05Y!7\-F#Q^$``````!(BVPD($4Q]NL39@\?1```26/&2(MLQ"!(A>UT.X!]
M``!T-4B)[T&#Q@'H0>[__X7`=-U(B>__%62(``!)B<=(A<`/A;C^__])8\9(
MBVS$($B%[77(#Q\`13'_Z:#^__^+A"2H````)0#P```]`$````^%+____T2+
MO"2L````_Q7#A@``03G'#X48____BX0DJ````"7_`0``/<`!```/A0'___],
MB??_%2J'``!(C3T_*0``3(GF28G&,<#H3NO__TB)QTB%P`^$0@(``/\5S(<`
M`$F+?0!(B<;HP//__TF)QTB%P`^$)`(``$R)__\50X8``(/X`WX^2&/0N04`
M``!(C3TI*0``28UT%_SSI@^7PH#:`(32=1Z#^`0/A(D#``"#Z`5(F$&`/`<O
M#X1Y`P``#Q]$``"+!9*'``"#^/\/A"D#``"%P`^$U`$``$B--9$H``!(C3T2
M*```,<#H7.___TR-)04I``!,C2U:)P``_Q6`A0``051)B>B^`0```%!(Q\+_
M____3(GW,<!,C0TV)P``2(T-KB@``/\5%8<``%A:ZTUF#Q^$``````#_%0J%
M``"#.!%U3/\5-X4``(/#`4B#[`A-B>E!5$F)Z$B-#8(H``!,B?=32,?"____
M_[X!````4#'`_Q7(A@``2(/$(+[``0``3(GW_Q7>A```@_C_=*E(B>__%:B$
M``!,B?9(C3T`)P``,<#HG^[__TR)]^@G^O__Z9W]__]FD#';2(T]P"<``.L2
M#Q]$``!(8\-(BWS$0$B%_W0Y3(GF,<"#PP'HMNG__TB%P'3A@#@`=-Q(B<?_
M%3.&``!(B<5(A<`/A<O[__](8\-(BWS$0$B%_W7'OPT```!(C2UL)P``_Q5`
MA0``0;A3````2(G#Z;_[__])BTT`2(L];X8``$F)Z#'`2(T5VR<``+X!````
M13'V_Q7%A0``Z?O\__](B<?H>/G__TB+A"1X@0``9$@K!"4H````#X5L`@``
M2('$B($``$B)[UM=05Q!74%>05__)9>%```/'X``````38M]`.G3_?__QP6M
MA0```````#'V3(G_,<#_%0"%``!!B<2%P`^$%/[__TB-G"1P`0``N@(```!(
MQ\;N____B<?_%3&%``"Z!@```$B)WD2)Y_\5,(0``("\)'`!````=0Z`O"1Q
M`0``0P^$;P$``#'2,?9$B>?_%?N$```QP&?H2QT``$F)Q>L49@\?1```B<)(
MB=Y,B>]GZ)(=``"Z`(```$B)WD2)Y_\5V8,``(7`?]U,C;PD(`$``$2)YTR-
M)4HF``#_%9V#``!,B>Y,B?],C:PD:`$``&?H`1\``$B-A"1``0``2(E$)`A(
MB<.02(G?2(/#`D4/M@=,B>%(Q\+_____O@$````QP$F#QP'_%9*$``!).=UU
MU4B-!3XF``#&A"1H`0```%#_="002(T-]B4``$F)Z$R)]S'`O@$```!,C0UR
M)```2,?"______\5480``%E>Z9G]__]FD#'`3(GF2(T]\R0``.B/Y___2(7`
M#X2/_O__#[8`A,`/A(3^__\\,`^$?/[__\<%*80```$```#IH_S__TV+;0A-
MA>T/A'_\__],B>__%7:"``!(@_@##X9L_/__28UT!?RY!0```$B-/5HE``#S
MI@^7P!P`A,!-#T3]Z4G\__^`O"1R`0``00^%@_[__X"\)',!``!##X5U_O__
M@+PD=`$``$@/A6?^__^`O"1U`0``10^%6?[__[H"````2,?&QO___T2)Y_\5
M3(,``+HI````2(G>1(GG_Q5+@@``2(T%'"4``%!3Z>3^____%=^!``!F9BX/
M'X0```````\?0`!!5T%6055!5%532(/L*(L]7(,``&1(BP0E*````$B)1"08
M,<!,C70D%/\5,8(``(L].X,``$B)P_\5(H(```^VD[@```!,B?9(C3V4(P``
MB)"Y````,<#H1.;__TB%P'0)@#@Q#X0F`P``,<#H'_'__XL]^8(``/\5XX$`
M`+D+````N@$```!(C35L)```2(G'_Q6I@0``1(L]TH(``$B%P`^$X0```$B+
M0!"#/2Z3```!3(MH*`^.S````#';ZSA(BW802(L5#9,``$ECQ$B+/,+_%6"!
M``!!B<"+!?^2``!%A<`/A9,```"#Q0)$B>,YQ0^-A0```$2)_XG=1(UC`?\5
M68$``#')2&/33(GN2(G'_Q7`@0``2(7`=%-(BS!$BSU)@@``BT8,)0`$(``]
M``0``'2*1(G_2(ET)`C_%1R!``!(BW0D"+D"````,=)(B<?_%9^```!$BST0
M@@``2(G&Z5S___\/'X0``````(L%:I(``$2+/?.!``"-4/\YTP^$D`$``$2)
M__\5SX```+D#````N@$```!(C35=(P``2(G'_Q65@```2(G#2(7`=#=(BT`0
MBSVS@0``2(LH_Q6:@```2(T5-",``$B)QTB)[O\5%X```$B+0Q!(BRCV10Y`
M#X7C`0``BSV`@0``_Q5J@```N0,```"Z`0```$B--1@C``!(B<?_%3"```!(
MB<-(A<!T/TR)]DB-/9$A```QP.AWY/__28G$2(7`#X1K`0``2(M#$(L],8$`
M`$B+*/\5&(```$R)XDB)QTB)[O\5F7\``(L]$X$``/\5_7\``+H!````2(TU
MER(``$B)Q_\5^'\``(L]\H```$B)Q?\5V7\``$B-%8TB``!(B>Y(B<?_%59_
M``"+/="```#_%;I_``!,B?9(C3WZ(```QH"Y`````#'`Z.+C__](B04CD0``
M28G$2(7`#X2/````OL`!``!,B>?_%9%^``"-4`&#^@%V"8/X$0^%``$``$B+
M1"089$@K!"4H````#X7F````2(/$*%M=05Q!74%>05_##Q]$``"#^`$/CF?^
M__^[`0```&8N#Q^$``````!$B?^#PP'_%21_``!,B>Y(B<?_%3A^```Y'9*0
M``!$BST;@```?]GI+/[__P\?0`!(BSUQD```Z(3T__](B05UD```28G$2(7`
M#X52____2(T].B(``#'`_Q7J?@``9I"`>`$`#X37_/__Z<O\__^02(L%,9``
M`(L]PW\``$R+($B+0Q!(BRC_%:-^``!,B>9(B>_HF.;__^F*_O__BSV=?P``
M_Q6'?@``2(GN2(G'_Q6S?@``Z0#^____%>!]``")P4B+!=^/``!,B>)(C3WE
M(0``2(LP,<#_%6I^``!FD$%454B)_5-(@^P09$B+!"4H````2(E$)`@QP$B%
M_P^$O````(`_``^$LP```.A.Y?__#[802(G#A-)T%@\?0`!(@\`!@/HO#[80
M2`]$V(32=>Z+!?A^``!(A>U!#Y7$@_C_#X20````A<`/E<!!(<1%A.1U(TB+
M1"0(9$@K!"4H````#X6P````2(/$$%M=05S#9@\?1```@'T``'37N00```!(
MC3T#(```2(G>\Z8/E\`<`(3`=;U(BT0D"&1(*P0E*````'5Q2(/$$$B)[UM=
M05SIB.+__P\?A```````2(T]8QX``/\5,WX``.E`____9@\?1```,<!(C70D
M!$B-/>D>``#HA>'__TB%P'0+#[8`A,!T!#PP=0_'!2M^````````Z4O____'
M!1Q^```!````Z3?_____%8%\``"005=,C4\X059!54%455-(@>R8`@``9$B+
M!"4H````2(F$)(@"```QP$B)XDR-E"2`````28G09BX/'X0``````$&+`4F+
M,4F#P!!)@\$(#\B)P$B)\4F)0/!(B?!(P>D@2,'H*$C![C@E`/\``$@)\$B)
MSDC!X0A(P>88@>$``/\`B?9("?!("<A)B4#X33G0=:Y(C;(``@``#Q^`````
M`$B+0FA(,T)`2(/""$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](B4)X2#GR==5,
MBP],BU\02(MW($B+7QA,B<A,B<I(BV\(2,'J&TC!X`5("=`#!"2-E#"9>8):
M3(G82(MT)`A(,=A((>A(C;0SF7F"6D@QV$2-%`)(B>I(B>A(P>@"2,'B'DV)
MT$@)PDR)V$G!Z!N)T4@QR$PAR$PQV$@!\$R)UDC!Y@5,"<9$C30P3(G.3(G(
M2,'F'DC!Z`)-B?!("?!(BW0D$$G!Z!M(,<)!B<5,(=))C;0SF7F"6D@QRD@!
M\DR)]DC!Y@5,"<9$C00R3(G62<'J`DB+5"082,'F'DP)UDB-E!&9>8):3(G!
M2#'P08GT3"'P3#'H2,'I&T@!T$R)PDC!X@5("<I,B?%)P>X"2,'A'D2-%!!(
MB?!(BU0D($P)\4R)UD@QR$F-E!69>8):2,'N&T&)SDPAP$PQX$@!T$R)TDC!
MX@5("?)$C2P03(G"2<'H`DB+1"0H2,'B'DR)[DP)PDF-A`29>8):2,'N&T@Q
MT4&)T$PAT4PQ\4@!P4R)Z$C!X`5("?!$C20!3(G02<'J`DB+3"0P2,'@'DR)
MYDP)T$F-C`Z9>8):2#'"08G"3"'J3#'"2`'*3(GA2,'A!4C![AM("?%,B>Y)
MP>T"2,'F'D2--`I(BU0D.$P)[DR)\4@Q\$F-E!"9>8):2,'I&T&)]4PAX$PQ
MT$@!T$R)\DC!X@5("<I,B>%)P>P"2,'A'D2-!!!(B?!(BU0D0$P)X4R)QD@Q
MR$F-E!*9>8):2,'N&T&)S$PA\$PQZ$@!T$R)PDC!X@5("?)$C1003(GR2<'N
M`DB+1"1(2,'B'DR)UDP)\DF-A`69>8):2,'N&T@QT4&)UDPAP4PQX4@!P4R)
MT$C!X`5("?!$C2P!3(G`2<'H`DB+3"102,'@'DR)[DP)P$F-C`R9>8):2,'N
M&T@QPD&)P$PATDPQ\D@!RDR)Z4C!X05("?%,B=9)P>H"2,'F'D2-)`I(BU0D
M6$P)UDR)X4@Q\$F-E!:9>8):2,'I&T&)\DPAZ$PQP$@!T$R)XDC!X@5("<I,
MB>E)P>T"2,'A'D2--!!(B?!(BU0D8$P)Z4R)]D@QR$F-E!"9>8):2,'N&T&)
MS4PAX$PQT$@!T$R)\DC!X@5("?)$C0003(GB2(M$)&A(P>(>2<'L`DR)QDP)
MXDF-A`*9>8):2,'N&T@QT4&)U$PA\4PQZ4@!P4R)P$C!X`5("?!$C10!3(GP
M2<'N`DB+3"1P2,'@'DR)UDP)\$F-C`V9>8):2,'N&T@QPD&)QDPAPDPQXD@!
MRDR)T4C!X05("?%,B<9)P>@"2,'F'D2-+`I(BU0D>$P)QDR)Z4@Q\$F-E!29
M>8):2,'I&T&)\$PAT$PQ\$@!T$R)ZDC!X@5("<I,B=%)P>H"2,'A'D2-)!!(
MB?!(BY0D@````$P)T4R)YD@QR$F-E!:9>8):2,'N&T&)RDPAZ$PQP$@!T$R)
MXDC!X@5("?)$C3003(GJ2<'M`DB+A"2(````2,'B'DR)]DP)ZDF-A`"9>8):
M2,'N&T@QT4&)U4PAX4PQT4@!P4R)\$C!X`5("?!$C00!3(G@2<'L`DB+C"20
M````2,'@'DP)X$F-C`J9>8):38G"2#'"2<'J&XG&3"'R3#'J2`'*3(G!2,'A
M!4P)T4V)\DG![@))P>(>B<E-"?)(`<I(BXPDF````$PQT$&)U$PAP$F-C`V9
M>8):38GE2#'P2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)P4G!Z`)(P>$>08G%
M3`G!38G018G23`.4)*@```!),<A$,<),BX0DH````$Z-A`:AZ]EN3(GN20'0
M3(GJ2,'N&TC!X@5("?*)TDD!T$R)XDG![`)(P>(>1(G&3`GB28G,B<E(`XPD
ML````$DQU$0QX$F)]$V-E`*AZ]EN2(GP2<'L&TC!X`5,">")P$D!PDR)Z$G!
M[0)(P>`>18G43`GH28G5B=)),<5%,>A-B>5(`Y0DN````$Z-A`&AZ]EN3(GA
M2<'M&TC!X05,">F)R4P!P4F)\$C![@))P>`>08G-20GP2(G&B<!(`X0DP```
M`$PQQD$Q\DJ-M!*AZ]EN3(GJ38GJ2<'J&TC!X@5,"=*)TD@!\DR)YDG![`)(
MP>8>08G23`GF38G$18G`3`.$),@```!),?1$,>%-B=1(C8P(H>O9;DR)T$G!
M[!M(P>`%3`G@B<!(`<A,B>E)P>T"2,'A'D&)Q$P)Z4F)]8GV23'-1#'J38GE
M38V$$*'KV6Y,B>)(P>(%2<'M&T@#M"30````3`GJB=))`=!,B=))P>H"2,'B
M'D6)Q4P)TDF)RHG)2`.,)-@```!),=)$,=!-B>I(C;0&H>O9;DR)Z$G!ZAM(
MP>`%3`G0B<!(`<9,B>!)P>P"2,'@'D&)\DP)X$F)U(G22`.4).````!),<1%
M,>!-B=1.C80!H>O9;DR)T4G![!M(P>$%3`GAB<E,`<%-B>A)P>T"2<'@'D&)
MS$T)Z$F)Q8G`33'%1#'N38GE2(VT,J'KV6Y,B>))P>T;2,'B!4P)ZHG22`'R
M3(G62<'J`D@#A"3H````2,'F'D&)U4P)UDV)PD6)P$P#A"3P````23'R1#'1
M38GJ2(V,"*'KV6Y,B>A)P>H;2,'@!4P)T(G`2`'(3(GA2<'L`DC!X1Y!B<),
M">%)B?2)]D@#M"3X````23',1#'B38G438V$$*'KV6Y,B=))P>P;2,'B!4P)
MXHG220'03(GJ2<'M`DC!XAY%B<1,">I)B<V)R4DQU40QZ$V)Y4B-M`:AZ]EN
M3(G@2<'M&TC!X`5,">B)P$@!QDR)T$C!X!Y)P>H"08GU2`.,)``!``!,"=!)
MB=*)TD@#E"0(`0``23'"13'038GJ3HV$`:'KV6Y,B>E)P>H;2,'A!4P)T8G)
M3`'!38G@2<'L`DG!X!Y!B<I-">!)B<2)P$@#A"00`0``33'$1#'F38G42(VT
M,J'KV6Y,B=))P>P;2,'B!4P)XHG22`'R3(GN2<'M`DC!YAY!B=1,">Y-B<5%
MB<!),?5$,>E-B>5(C8P(H>O9;DR)X$G![1M(P>`%3`GHB<!(`<A,B=%)P>H"
M2,'A'D&)Q4P)T4F)\DP#A"08`0``B?9),<I(`[0D(`$``$0QTDV-M!"AZ]EN
M3(GJ38GH2<'H&TC!X@5,"<))B<B)R4@#C"0H`0``B=))`=9,B>))P>P"2,'B
M'D6)\DP)XDDQT$0QP$R-I`:AZ]EN3(G03(G62,'N&TC!X`5("?!(B=:)TD@#
ME"0P`0``B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$@QQD$Q]DR)QDZ-K#&AZ]EN
M3(G!2,'N&TC!X05("?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G128G"B<!),<I%
M,=1(`X0D.`$``$Z-E"*AZ]EN2(GR28GT2<'L&TC!X@5,">)-B<1)P>@"2<'D
M'D$!TDT)Q$F)R(G)33'@1(GB13'%3HV$**'KV6Y,B=!-B=5)P>T;2,'@!4P)
MZ$R+K"1``0``18TT`$F)\$C![@),B>!)P>`>20GP1(G&3`G`3"'022'T20G$
MN-R\&X])`<5,`>E-B?5,`>%-B?1)P>T;2<'D!4T)[$$!S$R)T4G!Z@)(P>$>
M3`G120G(28G-08G*32'P22'U30GH3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))
MP>T;2,'B!4P)ZD6-+!!,B?))P>X"2,'B'DP)\DF)SD&)T$D)UDTAYDPAP4P)
M\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30Q3(GF2<'L
M`DC!YAY,">9("?))B?2)\4TAQ$PAZDP)XDR+I"18`0``20'$30'B38GT3`'2
M38GR2<'B!4G![!M-">)&C20238GJ2<'M`DG!XAY-">I)B?5$B=)-"=5-(?5(
M(=9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH1HTL!DV)
M\$G![@))P>`>30GP30G"38G&1(G&22'632'B30GR3(NT)&@!``!)`<9,`?%-
MB>Y)`<I,B>E)P>X;2,'A!4P)\46--`I,B>%)P>P"2,'A'DP)X4V)Q$D)S$&)
MRDTA[$TAT$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L&TC!X@5,">)%
MC2003(GJ2<'M`DC!XAY,">I("=%)B=5!B=!-(=5,(?%,">E,BZPD>`$``$D!
MQ4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL,4R)]DG![@)(P>8>3`GV28G6
MB?%)"?9-(>9((<I,"?),B[0D@`$``$D!QDT!\DV)[DP!TDV)ZDG![AM)P>(%
M30GR1HTT$DV)XDG![`))P>(>30GB3`G638G41(G222',3"'N3`GF3(ND)(@!
M``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$:-)`9-B>A)P>T"2<'@'DT)
MZ$V)U42)QDT)Q4TA]4DA\DT)ZDR+K"20`0``20'%3`'I38GE20'*3(GA2<'M
M&TC!X05,">E%C2P*3(GQ2<'N`DC!X1Y,"?%)"<A)B<Y!B<I)(?9-(>!-"?!,
MB[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR18TT$$R)XDG![`)(
MP>(>3`GB28G,08G020G432'L3"'!3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,
MB?9)P>P;2,'F!4P)YD2-)#%,B>Y)P>T"2,'F'DP)[D@)\DF)]8GQ32'%3"'R
M3`GJ3(NL)*@!``!)`<5-`>I-B>5,`=)-B>))P>T;2<'B!4T)ZD:-+!)-B?))
MP>X"2<'B'DT)\DF)]D2)TDT)UDTAYD@AUDP)]DR+M"2P`0``20'&30'P38GN
M3`'&38GH2<'N&TG!X`5-"?!&C30&38G@2<'L`DG!X!Y-">!-"<)-B<1$B<9)
M(=1-(>I-">),BZ0DN`$``$D!Q$P!X4V)]$D!RDR)\4G![!M(P>$%3`GA18TD
M"DR)Z4C!X1Y)P>T"3`GI38G%08G*20G-32'U32'030GH3(NL),`!``!)`<5,
M`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD6-+!!,B?))P>X"2,'B'DP)\D@)T4F)
MT$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,
M"<9$C00Q3(GF2<'L`DB)T4C!YAY,">9!B?1("?%,(>E,(>)("<I(BXPDT`$`
M`$@!P4@#A"38`0``20'*3(G!20''3`'238G"2,'A!4G!ZAM,"=&)R4@!RDR)
MZ4G![0)(P>$>08G23`GI3(G02`G.28G-2,'@!4&)SDTAY4PAQDP)[DV)U4G!
M[1M,`?Y,">B)P$@!QDR)P$G!Z`)(P>`>08GU20G`N-;!8LI,,<$QRDB+C"3@
M`0``2`'!3`'A38GL2`'13(GJ2<'L&TC!X@5,">*)TD@!T4R)TDG!Z@)(P>(>
M08G,20G23(G"18G`3#'2,=9(BY0DZ`$``$@!PDD!UDR)XDP!]DV)YDC!X@5)
MP>X;3`GRB=),C3063(GJ2<'M`DR)UDC!XAY%B?=%B=))"=5(BY0D\`$``$PQ
M[D@!PC'Q3(G^3`'"2,'N&T@!T4R)^DC!X@5("?)(B[0D^`$``(G22`'13(GB
M2`'&2<'L`DC!XAY,`=9-B>I!B<A,">)-B<1%B>U),=)%,=9.C10V3(G&2,'F
M!4G![!M,">:)]DD!\DR)_DG![P)(P>8>18G420GW2(NT)``"``!(`<9,`>Y)
MB=6)TDTQ_40QZ4R-+`Y,B>%,B>9(P>X;2,'A!4@)\4R)QDG!Z`*)R4C!YAY)
M`<U(BXPD"`(``$P)QDV)^$DQ\$6)[D6)_T@!P44QPD@!RDR)\4Z-!!),B?)(
MP>D;2,'B!4@)RDB)\8GVB=))`=!,B>))P>P"2,'B'D6)PDD)U$B+E"00`@``
M3#'A2`'"03'-3(G13`'Z20'53(G22,'I&TC!X@5("<I,B?%)P>X"B=)(P>$>
M20'52(N4)!@"``!,"?%%B>](`<)(`?),B>9%B>1(,<Y!,?!,B?Y)`=!,B?I(
MP>X;2,'B!4@)\HG220'03(G22<'J`DC!XAY%B<9)"=)(BY0D(`(``$R)]DC!
M[AM(`<),`>))B<R)R4TQU$4QY4Z-)"I,B?)(P>(%2`GR2(NT)"@"``")TDD!
MU$R)^D@!QDG![P)(P>(>18GE3`GZ2`'Q3(G618G22#'603'P3(GN20'(3(GI
M2,'N&TC!X05("?&)R4D!R$R)\4G![@)(P>$>18G'20G.2(N,)#`"``!,B?Y(
MP>X;2`'!3`'128G2B=)-,?)%,=1.C10A3(GY2,'A!4@)\4R)[DG![0*)R4C!
MYAY)`<I(BXPD.`(``$P)[D6)U$@!P4@!RDR)\46)]D@Q\4$QR$R)X4D!T$R)
MXDC!Z1M(P>(%2`G*2(GQB?:)TDD!T$R)^DC!XAY)P>\"18G%20G72(N4)$`"
M``!,,?E(`<)!,<I,B>E,`?)(P>D;20'23(GJ2,'B!4@)RDR)X4G![`*)TDC!
MX1Y)`=)(BY0D2`(``$P)X46)_$6)UD@!PD@!\DR)_D@QSD$Q\$J--`),B?)-
MB?!)P>@;2,'B!4P)PHG22`'63(GJ2<'M`DC!XAY!B?!)"=5(BY0D4`(``$@!
MPDP!XDF)S(G)33'L13'B3HTD$DR)PDV)PDG!ZAM(P>(%3`G2B=))`=1,B?))
MP>X"2,'B'D6)XDP)\DR+M"18`@``20'&3`'Q38GN18GM23'61#'V38G62`'.
M3(G12<'N&TC!X05,"?&)R4@!SDR)P4G!Z`)(P>$>08GV20G(2(N,)&`"``!(
M`<%)`<U(B=&)TDPQP4$QS$N-3"4`38GT38GU2<'M&TG!Y`5-">Q-B=5)P>H"
M2<'E'D6)Y$T)ZDR+K"1H`@``3`'A08G,20'%3`'J38G%18G`33'51#'N3(TL
M,DR)XDR)YDC!X@5(P>X;2`GRB=))`=5,B?))P>X"2,'B'D2)[DD)UDB+E"1P
M`@``2`'"2`.$)'@"``!,`<)-B=!-,?!$,<%)B?!(`<I(B?%)P>@;2,'A!4P)
MP46)T`'13(GB2<'L`DC!XAY)"=1*C10(2(G(20'03(GR2,'@!40!XTPQXDB)
M7QA!,=5+C10H28G(`>E)P>@;2(E/"$P)P`'02(D'2(GP2,'N`DC!X!Y("<9!
M`?-$`W<@3(E?$$R)=R!(BX0DB`(``&1(*P0E*````'422('$F`(``%M=05Q!
M74%>05_#_Q5C9@``#Q\`2(/L"+^`````_Q7I9@``NHFKS>^Y_MRZF+[PX=+#
M2,<``2-%9TB)4`A(B4@02,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`
M>`````!(@\0(PV9F+@\?A```````05=(8\)!5DF)QD%5051)B?Q52(UO.%-(
MB?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`
M#X7M````08/^/P^.,P$``$&#[D!%B?=!P>\&18UO`4G!Y09)`=T/'T0``/,/
M;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=,.CAZ/__
M3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$F)5"0X28M4!?A(B50%^$B-50A(
M@^+X2"G522GM2`'%2(/E^$B#_0AR&$B#Y?@QP$F+3`4`2(D,`DB#P`A(.>AR
M[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5\2(7`=.%!#[95`$&(5"0XJ`)T
MTT$/MU0%_F:)5`7^Z\8/'T``0;U`````2(U\!0!(B=Y!*<5%.>Y%#T[N36/]
M3(GZ_Q4D90``08M$)'A$`>A!B40D>(/X0'613(GG12GN3`'[Z`3H___IRO[_
M_P\?@`````!)B=WI&____T&+50!!B50D.$&+5`7\B50%_.E3____9@\?A```
M````059,C78X055!5%5(B?532(M&*$B)^T2+9BA$BVXP2,'H`X/@/T$/S$$/
MS8U(`4B8QD0&.(!(8\%,`?"#^3@/CBP!``"^0````"G.=`\QTHG1@\(!Q@0(
M`#GR<O-(B>_H;.?__V8/[\`/$44X2<=&,`````!!#Q%&$$$/$48@1(EM<$B)
M[T2)973H0N?__TB+10!(B>](P>@8B`-(BT4`2,'H$(A#`4B+10!(P>@(B$,"
M2(M%`(A#`TB+10A(P>@8B$,$2(M%"$C!Z!"(0P5(BT4(2,'H"(A#!DB+10B(
M0P=(BT402,'H&(A#"$B+11!(P>@0B$,)2(M%$$C!Z`B(0PI(BT40B$,+2(M%
M&$C!Z!B(0PQ(BT482,'H$(A##4B+11A(P>@(B$,.2(M%&(A##TB+12!(P>@8
MB$,02(M%($C!Z!"(0Q%(BT4@2,'H"(A#$DB+12"(0Q-;74%<05U!7O\E8F(`
M`&8N#Q^$``````"Z.````#'_*<J#^@AR0HG12,<``````$C'1`CX`````$B-
M2`A(@^'X2"G(`<*#XOB#^@@/@M7^__^#XO@QP(G&@\`(2(D\,3G0<O/IOO[_
M__;"!'4CA=(/A+'^___&``#VP@(/A*7^__\QR6:)3!#^Z9G^__\/'P#'````
M``#'1!#\`````.F#_O__#Q]$``#S#Q[Z05=,C3UK7P``059)B=9!54F)]4%4
M08G\54B-+5Q?``!33"G]2(/L".B?P___2,']`W0?,=L/'X``````3(GR3(GN
M1(GG0?\4WTB#PP%(.=UUZDB#Q`A;74%<05U!7D%?PV9F+@\?A```````\P\>
M^L-F+@\?A```````D/,/'OI(BPU-8P``Z7##___S#Q[Z2(/L"$B#Q`C#````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"X`+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI0
M86-K97(Z.E9%4E-)3TX`,2XP-3``+64`+2T``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P``
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#._P````>````H(+__S`!``#`@O__U`4``-"$__\8`0``T(7__U@!``"@
MAO__I`$``#"(___H`0``P(C__PP"``"0B?__-`(``("*__]X`@``T(S__\0"
M``!`C?__W`(``("-___T`@``4([__R@#``!@CO__/`,``'"0__^<`P``H)#_
M_[`#``#`D/__Q`,``'"5___P`P``\)7__PP$```0EO__)`0``""7__]T!```
M,)___T0%``!`H___D`4``("D__\`!@``H+K__U`&````N___:`8``+"\__^T
M!@``L+[___@&```@O___0`<``#"___]8!P```````!0``````````7I2``%X
M$`$;#`<(D`$``!0````<````L(/__R\`````1`<0`````"0````T````:('_
M_R``````#A!&#AA*#PMW"(``/QH[*C,D(@````!(````7````'"$___-````
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)M"@XX1`XP00XH
M0@X@0@X80@X00@X(2`L`0````*@```#TA/__C0$```!"#A".`D(.&(T#0@X@
MC`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+"P`@````[```
M`$"&__^,`````$$.$(8"4@ZP`0)Q"@X000X(00LD````$`$``*R&___&````
M`$$.$(8"`EL*#@A,"P)!"@X(00M6#@@`0````#@!``!4A___YP````!"#A"/
M`D<.&(X#0@X@C01"#BB,!40.,(8&40[`(`*&"@XP00XH0@X@0@X80@X00@X(
M1PM(````?`$```"(__]"`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$
M#CB#!T<.4`,=`0H..$$.,$$.*$(.($(.&$(.$$(."$4+%````,@!```$BO__
M;@````!$#A`"9`X(%````.`!``!<BO__,@````!$#A!7#@@`,````/@!``"$
MBO__Q0````!"#A",`D$.&(8#00X@@P1'#L!``JP*#B!$#AA!#A!"#@A!"Q``
M```L`@``((O__P4`````````7````$`"```<B___!0(```!"#A"/`D(.&(X#
M0@X@C01%#BB,!4$.,(8&2PXX@P='#O`A`F4*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A#"P*N#O@A2`Z`(F0.^"%!#O`A````$````*`"``#,C/__)0`````````0
M````M`(``.B,__\=`````````"@```#(`@``](S__Z<$````00X0A@)!#AB#
M`TL.8`-'!`H.&$$.$$$."$$+&````/0"``!XD?__=0````!$#B!M"@X(1PL`
M`!0````0`P``W)'__Q\`````1`X06@X(`$P````H`P``Y)'__Q`!````0@X0
MC`)!#AB&`TL.((,$1`XP`D(*#B!*#AA!#A!"#@A/"V4*#B!!#AA!#A!"#@A'
M"V0..$D.0&0..$$.,```S````'@#``"DDO__`0@```!"#A"/`D(.&(X#0@X@
MC01,#BB,!4$.,(8&00XX@P='#L"#`@.O`0[(@P)A#M"#`F$.R(,"0@[`@P("
M>PH..$0.,$$.*$(.($(.&$(.$$(."$H+`WH!#LB#`DD.T(,"80[(@P)!#L"#
M`F,.R(,"10[0@P).#MB#`DT.X(,"3`[`@P(#`@$*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A-"P,K`0[(@P)$#M"#`FD.R(,"00[`@P("[`H.R(,"00[0@P)%"T@`
M``!(!```Y)G__PX$````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'
M1`Y@`_H""@XX00XP00XH0@X@0@X80@X00@X(1@M`````E`0``*B=__\_`0``
M`$(.$(P"00X8A@-$#B"#!$0.,`*""@X@00X800X00@X(1PMT"@X@1`X800X0
M0@X(30L``"@```#8!```Y'S__Q`"````0@X0C`)!#AB&`T0.4`.L`0H.&$0.
M$$(."$$+3`````0%``!XGO__'18```!"#A"/`D8.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P='#M`%`_<5"@XX00XP00XH0@X@0@X80@X00@X(00L````4````
M5`4``$BT__]5`````$0.$`)0#@A(````;`4``)"T__^G`0```$(.$(\"10X8
MC@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX00XP00XH0@X@0@X80@X0
M0@X(0PL`0````+@%``#TM?__^P$```!"#A".`D8.&(T#0@X@C`1!#BB&!40.
M,(,&`TH!"@XH00X@0@X80@X00@X(4`L```````!$````_`4``+"W__]E````
M`$8.$(\"20X8C@-%#B"-!$4.*(P%1`XPA@9(#CB#!T<.0&X..$$.,$$.*$(.
M($(.&$(.$$(."``4````1`8``-BW__\%```````````````0````7`8``-"W
M__\0````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````0",```````#P(@````````$`````
M````(`,````````!`````````"L#`````````0`````````[`P````````\`
M````````Q@0````````,```````````@````````#0````````#`7```````
M`!D`````````J+L````````;``````````@`````````&@````````"PNP``
M`````!P`````````"`````````#U_O]O``````@#````````!0`````````0
M#@````````8`````````L`0````````*`````````.D$````````"P``````
M```8`````````!4````````````````````#`````````-B]`````````@``
M```````8`````````!0`````````!P`````````7`````````"`;````````
M!P````````!(%`````````@`````````V`8````````)`````````!@`````
M````&````````````````````/O__V\``````0``"`````#^__]O`````,@3
M````````____;P`````"`````````/#__V\`````^A(```````#Y__]O````
M``0`````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"X
MNP`````````````````````````````V(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3`N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````*@"````````J`(````````<````````````
M`````````0```````````````````!,````'`````@````````#$`@``````
M`,0"````````)`````````````````````0````````````````````F````
M!P````(`````````Z`(```````#H`@```````"`````````````````````$
M````````````````````-````/;__V\"``````````@#````````"`,`````
M``"H`0````````4`````````"````````````````````#X````+`````@``
M``````"P!````````+`$````````8`D````````&`````0````@`````````
M&`````````!&`````P````(`````````$`X````````0#@```````.D$````
M```````````````!````````````````````3@```/___V\"`````````/H2
M````````^A(```````#(``````````4``````````@`````````"````````
M`%L```#^__]O`@````````#($P```````,@3````````@``````````&````
M`@````@```````````````````!J````!`````(`````````2!0```````!(
M%````````-@&````````!0`````````(`````````!@`````````=`````0`
M``!"`````````"`;````````(!L````````8``````````4````5````"```
M```````8`````````'X````!````!@``````````(``````````@````````
M&P````````````````````0```````````````````!Y`````0````8`````
M````("`````````@(````````"`````````````````````0`````````!``
M````````A`````$````&`````````$`@````````0"````````"`/```````
M````````````$````````````````````(H````!````!@````````#`7```
M`````,!<````````#0````````````````````0```````````````````"0
M`````0````(``````````&``````````8````````(`]````````````````
M```0````````````````````F`````$````"`````````("=````````@)T`
M``````#\````````````````````!````````````````````*8````!````
M`@````````"`G@```````(">````````<`8```````````````````@`````
M``````````````"P````#@````,`````````J+L```````"HJP````````@`
M```````````````````(``````````@`````````O`````\````#````````
M`+"[````````L*L````````(````````````````````"``````````(````
M`````,@````&`````P````````"XNP```````+BK````````(`(````````&
M``````````@`````````$`````````#1`````0````,`````````V+T`````
M``#8K0```````"@"```````````````````(``````````@`````````U@``
M``$````#``````````#``````````+`````````@````````````````````
M"````````````````````-P````(`````P`````````@P````````""P````
M````B!```````````````````"````````````````````#A`````0```#``
M```````````````````@L````````!(````````````````````!````````
M``$``````````0````,`````````````````````````,K````````#J````
<`````````````````0``````````````````````
